@@ -132,9 +132,9 @@ def banner():
     Function prints pocsuite banner with its version
     """
     _ = BANNER
-    if not getattr(LOGGER_HANDLER, "is_tty", False):
-        _ = clear_colors(_)
-    elif IS_WIN:
+    # if not getattr(LOGGER_HANDLER, "is_tty", False):
+    #     _ = clear_colors(_)
+    if IS_WIN:
         coloramainit()
 
     data_to_stdout(_)
@@ -172,7 +172,7 @@ def data_to_stdout(data, bold=False):
     """
     Writes text to the stdout (console) stream
     """
-    if 'quiet' not in conf or not conf.quiet:
+    if not conf.get('quiet', False):
         message = ""
 
         if isinstance(data, str):
@@ -384,19 +384,41 @@ def get_file_items(filename, comment_prefix='#', unicode=True, lowercase=False,
     return ret if not unique else ret.keys()
 
 
-def parse_target(address, additional_ports=[]):
+def parse_target(address, additional_ports=[], skip_target_port=False):
     # parse IPv4/IPv6 CIDR
     targets = OrderedSet()
     try:
-        for ip in ip_network(address, strict=False).hosts():
+        hosts = list(ip_network(address, strict=False).hosts())
+        '''
+        fix https://github.com/knownsec/pocsuite3/issues/319
+        different python versions have different behaviors on ipaddress library
+        '''
+        try:
+            t = ip_address(address.replace('/32', '').replace('/128', ''))
+            if t not in hosts:
+                hosts.append(t)
+        except ValueError:
+            pass
+
+        for ip in hosts:
 
             if ip.version == 6:
                 conf.ipv6 = True
 
-            targets.add(str(ip))
+            if not skip_target_port:
+                targets.add(str(ip))
 
-            for port in additional_ports:
-                targets.add(f'[{ip}]:{port}' if conf.ipv6 else f'{ip}:{port}')
+            for probe in additional_ports:
+                probe = str(probe)
+                # [proto:]port
+                scheme, port = '', probe
+                if len(probe.split(':')) == 2:
+                    scheme, port = probe.split(':')
+
+                if scheme:
+                    targets.add(f'{scheme}://[{ip}]:{port}' if conf.get('ipv6', False) else f'{scheme}://{ip}:{port}')
+                else:
+                    targets.add(f'[{ip}]:{port}' if conf.get('ipv6', False) else f'{ip}:{port}')
 
         return targets
 
@@ -410,13 +432,24 @@ def parse_target(address, additional_ports=[]):
     except ValueError:
         pass
 
-    targets.add(address)
+    if not skip_target_port:
+        targets.add(address)
 
     try:
         pr = urlparse(address)
-        for port in additional_ports:
-            netloc = f'[{pr.hostname}]:{port}' if conf.ipv6 else f'{pr.hostname}:{port}'
-            t = pr._replace(netloc=netloc).geturl()
+        for probe in additional_ports:
+            probe = str(probe)
+            # [proto:]port
+            scheme, port = '', probe
+            if len(probe.split(':')) == 2:
+                scheme, port = probe.split(':')
+
+            netloc = f'[{pr.hostname}]:{port}' if conf.get('ipv6', False) else f'{pr.hostname}:{port}'
+            t = pr._replace(netloc=netloc)
+            if scheme:
+                t = t._replace(scheme=scheme)
+
+            t = t.geturl()
             if t.startswith('tcp://'):
                 t = t.lstrip('tcp://')
             targets.add(t)
@@ -995,7 +1028,7 @@ def mosaic(s):
     """
 
     s = str(s)
-    if not ('ppt' in conf and conf.ppt):
+    if not conf.get('ppt', False):
         return s
 
     scheme = ''
