@@ -6,11 +6,11 @@ import inspect
 from collections import OrderedDict
 
 from requests.exceptions import ConnectTimeout, ConnectionError, HTTPError, TooManyRedirects
-from pocsuite3.lib.core.common import parse_target_url, mosaic, check_port, OrderedSet, get_host_ip
+from pocsuite3.lib.core.common import mosaic, check_port, OrderedSet, get_host_ip
 from pocsuite3.lib.core.data import conf, logger
 from pocsuite3.lib.core.enums import OUTPUT_STATUS, CUSTOM_LOGGING, ERROR_TYPE_ID, POC_CATEGORY
 from pocsuite3.lib.core.exception import PocsuiteValidationException
-from pocsuite3.lib.core.interpreter_option import OptString, OptInteger, OptPort, OptBool
+from pocsuite3.lib.core.interpreter_option import OptString, OptInteger, OptPort
 from pocsuite3.lib.request import requests
 from pocsuite3.lib.utils import urlparse
 
@@ -44,11 +44,13 @@ class POCBase(object):
         self.scheme = None
         self.rhost = None
         self.rport = None
+        self.netloc = None
         self.mode = None
         self.params = None
         self.verbose = None
         self.expt = (0, 'None')
         self.current_protocol = getattr(self, "protocol", POC_CATEGORY.PROTOCOL.HTTP)
+        self.current_protocol_port = getattr(self, "protocol_default_port", 0)
         self.pocDesc = getattr(self, "pocDesc", "Poc的作者好懒呀！")
         self.host_ip = get_host_ip(check_private=False)
 
@@ -64,15 +66,14 @@ class POCBase(object):
                 "", "Use a proxy to connect to the target URL (protocol://host:port)")
             self.global_options["timeout"] = OptInteger(10, "Seconds to wait before timeout connection (default 10)")
         else:
-            self.global_options["rhost"] = OptString('', require=True)
-            self.global_options["rport"] = OptPort('', require=True)
-            self.global_options["ssl"] = OptBool(default=False)
+            self.global_options["rhost"] = OptString('', 'The target host', require=True)
+            self.global_options["rport"] = OptPort('', 'The target port', require=True)
 
         # payload options for exploit
         self.payload_options = OrderedDict()
         if hasattr(self, "_shell"):
-            self.payload_options["lhost"] = OptString('', "Connect back ip", require=True)
-            self.payload_options["lport"] = OptPort(10086, "Connect back port")
+            self.payload_options["lhost"] = OptString(self.host_ip, "The listen address")
+            self.payload_options["lport"] = OptPort(6666, "The listen port")
 
         self.options = OrderedDict()
         # module options init
@@ -163,19 +164,61 @@ class POCBase(object):
         return True
 
     def build_url(self):
-        target = parse_target_url(self.target)
+        target = self.target
+        # https://en.wikipedia.org/wiki/List_of_TCP_and_UDP_port_numbers
+        protocol_default_port_map = {
+            POC_CATEGORY.PROTOCOL.FTP: 21,
+            POC_CATEGORY.PROTOCOL.SSH: 22,
+            POC_CATEGORY.PROTOCOL.TELNET: 23,
+            POC_CATEGORY.PROTOCOL.REDIS: 6379,
+            POC_CATEGORY.PROTOCOL.SMTP: 25,
+            POC_CATEGORY.PROTOCOL.DNS: 53,
+            POC_CATEGORY.PROTOCOL.SNMP: 161,
+            POC_CATEGORY.PROTOCOL.SMB: 445,
+            POC_CATEGORY.PROTOCOL.MQTT: 1883,
+            POC_CATEGORY.PROTOCOL.MYSQL: 3306,
+            POC_CATEGORY.PROTOCOL.RDP: 3389,
+            POC_CATEGORY.PROTOCOL.UPNP: 1900,
+            POC_CATEGORY.PROTOCOL.AJP: 8009,
+            POC_CATEGORY.PROTOCOL.XMPP: 5222,
+            POC_CATEGORY.PROTOCOL.WINBOX: 8291,
+            POC_CATEGORY.PROTOCOL.MEMCACHED: 11211,
+            POC_CATEGORY.PROTOCOL.BACNET: 47808,
+            POC_CATEGORY.PROTOCOL.T3: 7001,
+        }
+
+        if self.current_protocol_port:
+            protocol_default_port_map[self.current_protocol] = self.current_protocol_port
+
         try:
             pr = urlparse(target)
-            self.scheme = 'https' if pr.scheme.startswith('https') else 'http'
+            self.scheme = pr.scheme
             self.rhost = pr.hostname
-            self.rport = pr.port if pr.port else 443 if pr.scheme.startswith('https') else 80
+            self.rport = pr.port or self.current_protocol_port
+
+            # if protocol is not provided and the port endswith 443, we adjust the protocol to https
+            if (self.current_protocol not in protocol_default_port_map or
+                    self.current_protocol == POC_CATEGORY.PROTOCOL.HTTP):
+                if self.scheme not in ['http', 'https']:
+                    self.scheme = 'https' if str(self.rport).endswith('443') else 'http'
+                self.rport = self.rport if self.rport else 443 if self.scheme == 'https' else 80
+
+            else:
+                # adjust protocol
+                self.scheme = self.current_protocol.lower()
+                # adjust port
+                if not self.rport:
+                    self.rport = protocol_default_port_map[self.current_protocol]
+            self.netloc = f'{self.rhost}:{self.rport}'
+            pr = pr._replace(scheme=self.scheme)
+            pr = pr._replace(netloc=self.netloc)
+            target = pr.geturl()
         except ValueError:
             pass
         if self.target and self.current_protocol != POC_CATEGORY.PROTOCOL.HTTP and not conf.console_mode:
-            self.setg_option("rport", self.rport)
             self.setg_option("rhost", self.rhost)
-            self.setg_option("ssl", self.scheme == 'https')
-        return target
+            self.setg_option("rport", self.rport)
+        return target.rstrip('/')
 
     def _execute(self):
         if self.mode == 'shell':
@@ -192,6 +235,8 @@ class POCBase(object):
     def execute(self, target, headers=None, params=None, mode='verify', verbose=True):
         self.target = target
         self.url = self.build_url()
+        if self.url != self.target:
+            logger.debug(f'auto correct url: {mosaic(self.target)} -> {mosaic(self.url)}')
         # TODO: Thread safe problem in self.headers
         # https://github.com/knownsec/pocsuite3/issues/262
         # The value should not be modified in PoC Plugin !!!
@@ -257,17 +302,25 @@ class POCBase(object):
         return output
 
     def _check(self, dork='', allow_redirects=False, return_obj=False, is_http=True, honeypot_check=True):
-        self.url = self.url.rstrip('/')
         u = urlparse(self.url)
         # the port closed
         if u.port and not check_port(u.hostname, u.port):
             logger.debug(f'{mosaic(self.url)}, the port is closed.')
             return False
 
-        if not is_http:
+        if is_http is False or self.current_protocol != POC_CATEGORY.PROTOCOL.HTTP:
             return True
 
         res = None
+        corrected = False
+        # this only covers most cases
+        redirect_https_keyword = [
+            # https://www.zoomeye.org/searchResult?q=%22request%20was%20sent%20to%20HTTPS%20port%22
+            'request was sent to https port',
+            # https://www.zoomeye.org/searchResult?q=%22running%20in%20SSL%20mode.%20Try%22
+            'running in ssl mode. try'
+        ]
+        origin_url = self.url
         netloc = self.url.split('://', 1)[-1]
         urls = OrderedSet()
         urls.add(self.url)
@@ -278,22 +331,26 @@ class POCBase(object):
                 time.sleep(0.5)
                 res = requests.get(url, allow_redirects=allow_redirects)
                 # access ok, the url need to be correct
-                if 'plain HTTP request was sent to HTTPS port' in res.text:
-                    self.url = f'https://{netloc}'
-                    res = requests.get(self.url, allow_redirects=allow_redirects)
-                    logger.warn(f'auto correct url to: {mosaic(self.url)}')
+                for k in redirect_https_keyword:
+                    if k.lower() in res.text.lower():
+                        self.url = f'https://{netloc}'
+                        res = requests.get(self.url, allow_redirects=allow_redirects)
+                        logger.warn(f'auto correct url: {mosaic(origin_url)} -> {mosaic(self.url)}')
+                        corrected = True
+                        break
                 # another protocol is access ok
-                elif url != self.url:
+                if not corrected and url != self.url:
                     self.url = url
-                    logger.warn(f'auto correct url to: {mosaic(self.url)}')
+                    logger.warn(f'auto correct url: {mosaic(origin_url)} -> {mosaic(self.url)}')
                 break
             except requests.RequestException:
                 pass
 
-        if not self.url.startswith(self.scheme):
+        if self.url.split('://')[0] != self.scheme:
             self.scheme = 'https' if self.url.startswith('https') else 'http'
             port = urlparse(self.url).port
             self.rport = port if port else 443 if self.scheme.startswith('https') else 80
+            self.netloc = f'{self.rhost}:{self.rport}'
 
         if return_obj:
             return res
